ATel #12500: Spectroscopic Classifications of Optical Transients with SOAR

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 09:19 UT | This space for free for your conference.

[ Previous | Next | ADS ] # Spectroscopic Classifications of Optical Transients with SOAR ATel #12500; M. R. Siebert, D. A. Coulter, J. S. Brown, G. Dimitriadis, R. J. Foley (UCSC) on 12 Feb 2019; 23:31 UT Distributed as an Instant Email Notice Supernovae Credential Certification: Matthew Siebert (msiebert@ucsc.edu) Subjects: Optical, Supernovae Tweet We report the following classification of an optical transient from spectroscopic observations with the Goodman spectrograph on the Southern Astrophysical Research (SOAR) telescope. The target was supplied by Gaia. All observations were made on 2019 February 12 UT. Classifications were performed with SNID (Blondin & Tonry, 2007, ApJ, 666, 1024).
    Name         | IAU Name  | RA (J2000)  | Dec (J2000)  |   z   | Type  | Phase  | Notes

    Gaia19amg    | AT2019aox | 04:12:15.000| -06:42:09.29 | 0.031 |  Ia   |  -3 d  | (1)
Notes: When the redshift is given to 2 decimal places, it is derived from the SN spectrum. Otherwise, the redshift is determined from the host galaxy. (1) We measure an Si II 6355 velocity of -11,300 km/s. |